All Classes and Interfaces

Classes
Class
Description
Benchmark of double precision DCT's
Benchmark of double precision DHT's
Benchmark of double precision DST's
Benchmark of single precision FFT's
Benchmark of single precision DCT's
Benchmark of single precision DHT's
Benchmark of single precision DST's
Benchmark of single precision FFT's
Static utility methods.
Computes 1D Discrete Cosine Transform (DCT) of double precision data.
Computes 2D Discrete Cosine Transform (DCT) of double precision data.
Computes 3D Discrete Cosine Transform (DCT) of double precision data.
Computes 1D Discrete Hartley Transform (DHT) of real, double precision data.
Computes 2D Discrete Hartley Transform (DHT) of real, double precision data.
Computes 3D Discrete Hartley Transform (DHT) of real, double precision data.
Computes 1D Discrete Sine Transform (DST) of double precision data.
Computes 2D Discrete Sine Transform (DST) of double precision data.
Computes 3D Discrete Sine Transform (DST) of double precision data.
Computes 1D Discrete Fourier Transform (DFT) of complex and real, double precision data.
Computes 2D Discrete Fourier Transform (DFT) of complex and real, double precision data.
Computes 3D Discrete Fourier Transform (DFT) of complex and real, double precision data.
Computes 1D Discrete Cosine Transform (DCT) of single precision data.
Computes 2D Discrete Cosine Transform (DCT) of single precision data.
Computes 3D Discrete Cosine Transform (DCT) of single precision data.
Computes 1D Discrete Hartley Transform (DHT) of real, single precision data.
Computes 2D Discrete Hartley Transform (DHT) of real, single precision data.
Computes 3D Discrete Hartley Transform (DHT) of real, single precision data.
Computes 1D Discrete Sine Transform (DST) of float precision data.
Computes 2D Discrete Sine Transform (DST) of single precision data.
Computes 3D Discrete Sine Transform (DST) of single precision data.
Computes 1D Discrete Fourier Transform (DFT) of complex and real, single precision data.
Computes 2D Discrete Fourier Transform (DFT) of complex and real, single precision data.
Computes 3D Discrete Fourier Transform (DFT) of complex and real, single precision data.
I/O utilities.
This is a set of utility methods for R/W access to data resulting from a call to the Fourier transform of real data.
This is a set of utility methods for R/W access to data resulting from a call to the Fourier transform of real data.