Class FloatDHT_2D

java.lang.Object
org.jtransforms.dht.FloatDHT_2D

public class FloatDHT_2D extends Object
Computes 2D Discrete Hartley Transform (DHT) of real, single precision data. The sizes of both dimensions can be arbitrary numbers. This is a parallel implementation optimized for SMP systems.

Part of code is derived from General Purpose FFT Package written by Takuya Ooura (http://www.kurims.kyoto-u.ac.jp/~ooura/fft.html)
Author:
Piotr Wendykier ([email protected])
  • Constructor Summary

    Constructors
    Constructor
    Description
    FloatDHT_2D(long rows, long columns)
    Creates new instance of FloatDHT_2D.
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    forward(float[] a)
    Computes 2D real, forward DHT leaving the result in a.
    void
    forward(float[][] a)
    Computes 2D real, forward DHT leaving the result in a.
    void
    forward(org.visnow.jlargearrays.FloatLargeArray a)
    Computes 2D real, forward DHT leaving the result in a.
    void
    inverse(float[][] a, boolean scale)
    Computes 2D real, inverse DHT leaving the result in a.
    void
    inverse(float[] a, boolean scale)
    Computes 2D real, inverse DHT leaving the result in a.
    void
    inverse(org.visnow.jlargearrays.FloatLargeArray a, boolean scale)
    Computes 2D real, inverse DHT leaving the result in a.

    Methods inherited from class Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • FloatDHT_2D

      public FloatDHT_2D(long rows, long columns)
      Creates new instance of FloatDHT_2D.
      Parameters:
      rows - number of rows
      columns - number of columns
  • Method Details

    • forward

      public void forward(float[] a)
      Computes 2D real, forward DHT leaving the result in a. The data is stored in 1D array in row-major order.
      Parameters:
      a - data to transform
    • forward

      public void forward(org.visnow.jlargearrays.FloatLargeArray a)
      Computes 2D real, forward DHT leaving the result in a. The data is stored in 1D array in row-major order.
      Parameters:
      a - data to transform
    • forward

      public void forward(float[][] a)
      Computes 2D real, forward DHT leaving the result in a. The data is stored in 2D array.
      Parameters:
      a - data to transform
    • inverse

      public void inverse(float[] a, boolean scale)
      Computes 2D real, inverse DHT leaving the result in a. The data is stored in 1D array in row-major order.
      Parameters:
      a - data to transform
      scale - if true then scaling is performed
    • inverse

      public void inverse(org.visnow.jlargearrays.FloatLargeArray a, boolean scale)
      Computes 2D real, inverse DHT leaving the result in a. The data is stored in 1D array in row-major order.
      Parameters:
      a - data to transform
      scale - if true then scaling is performed
    • inverse

      public void inverse(float[][] a, boolean scale)
      Computes 2D real, inverse DHT leaving the result in a. The data is stored in 2D array.
      Parameters:
      a - data to transform
      scale - if true then scaling is performed