Class CommonUtils
java.lang.Object
org.jtransforms.utils.CommonUtils
Static utility methods.
- Author:
- Piotr Wendykier ([email protected])
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic voidbitrv2(int n, int[] ip, double[] a, int offa) static voidbitrv2(int n, int[] ip, float[] a, int offa) static voidbitrv208(double[] a, int offa) static voidbitrv208(float[] a, int offa) static voidbitrv208(org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidbitrv208(org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidbitrv208neg(double[] a, int offa) static voidbitrv208neg(float[] a, int offa) static voidbitrv208neg(org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidbitrv208neg(org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidbitrv216(double[] a, int offa) static voidbitrv216(float[] a, int offa) static voidbitrv216(org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidbitrv216(org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidbitrv216neg(double[] a, int offa) static voidbitrv216neg(float[] a, int offa) static voidbitrv216neg(org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidbitrv216neg(org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidbitrv2conj(int n, int[] ip, double[] a, int offa) static voidbitrv2conj(int n, int[] ip, float[] a, int offa) static voidbitrv2conj(long n, org.visnow.jlargearrays.LongLargeArray ip, org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidbitrv2conj(long n, org.visnow.jlargearrays.LongLargeArray ip, org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidbitrv2l(long n, org.visnow.jlargearrays.LongLargeArray ip, org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidbitrv2l(long n, org.visnow.jlargearrays.LongLargeArray ip, org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidcftb040(double[] a, int offa) static voidcftb040(float[] a, int offa) static voidcftb040(org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidcftb040(org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidcftb1st(int n, double[] a, int offa, double[] w, int startw) static voidcftb1st(int n, float[] a, int offa, float[] w, int startw) static voidcftb1st(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) static voidcftb1st(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) static voidcftbsub(int n, double[] a, int offa, int[] ip, int nw, double[] w) static voidcftbsub(int n, float[] a, int offa, int[] ip, int nw, float[] w) static voidcftbsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.LongLargeArray ip, long nw, org.visnow.jlargearrays.DoubleLargeArray w) static voidcftbsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.LongLargeArray ip, long nw, org.visnow.jlargearrays.FloatLargeArray w) static voidcftf040(double[] a, int offa) static voidcftf040(float[] a, int offa) static voidcftf040(org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidcftf040(org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidcftf081(double[] a, int offa, double[] w, int startw) static voidcftf081(float[] a, int offa, float[] w, int startw) static voidcftf081(org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) static voidcftf081(org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) static voidcftf082(double[] a, int offa, double[] w, int startw) static voidcftf082(float[] a, int offa, float[] w, int startw) static voidcftf082(org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) static voidcftf082(org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) static voidcftf161(double[] a, int offa, double[] w, int startw) static voidcftf161(float[] a, int offa, float[] w, int startw) static voidcftf161(org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) static voidcftf161(org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) static voidcftf162(double[] a, int offa, double[] w, int startw) static voidcftf162(float[] a, int offa, float[] w, int startw) static voidcftf162(org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) static voidcftf162(org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) static voidcftf1st(int n, double[] a, int offa, double[] w, int startw) static voidcftf1st(int n, float[] a, int offa, float[] w, int startw) static voidcftf1st(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) static voidcftf1st(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) static voidcftfsub(int n, double[] a, int offa, int[] ip, int nw, double[] w) static voidcftfsub(int n, float[] a, int offa, int[] ip, int nw, float[] w) static voidcftfsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.LongLargeArray ip, long nw, org.visnow.jlargearrays.DoubleLargeArray w) static voidcftfsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.LongLargeArray ip, long nw, org.visnow.jlargearrays.FloatLargeArray w) static voidcftfx41(int n, double[] a, int offa, int nw, double[] w) static voidcftfx41(int n, float[] a, int offa, int nw, float[] w) static voidcftfx41(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) static voidcftfx41(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) static voidcftleaf(int n, int isplt, double[] a, int offa, int nw, double[] w) static voidcftleaf(int n, int isplt, float[] a, int offa, int nw, float[] w) static voidcftleaf(long n, long isplt, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) static voidcftleaf(long n, long isplt, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) static voidcftmdl1(int n, double[] a, int offa, double[] w, int startw) static voidcftmdl1(int n, float[] a, int offa, float[] w, int startw) static voidcftmdl1(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) static voidcftmdl1(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) static voidcftmdl2(int n, double[] a, int offa, double[] w, int startw) static voidcftmdl2(int n, float[] a, int offa, float[] w, int startw) static voidcftmdl2(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) static voidcftmdl2(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) static voidcftrec4(int n, double[] a, int offa, int nw, double[] w) static voidcftrec4(int n, float[] a, int offa, int nw, float[] w) static voidcftrec4(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) static voidcftrec4(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) static voidcftrec4_th(int n, double[] a, int offa, int nw, double[] w) static voidcftrec4_th(int n, float[] a, int offa, int nw, float[] w) static voidcftrec4_th(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) static voidcftrec4_th(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) static intcfttree(int n, int j, int k, double[] a, int offa, int nw, double[] w) static intcfttree(int n, int j, int k, float[] a, int offa, int nw, float[] w) static longcfttree(long n, long j, long k, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) static longcfttree(long n, long j, long k, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) static voidcftx020(double[] a, int offa) static voidcftx020(float[] a, int offa) static voidcftx020(org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidcftx020(org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidcftxb020(double[] a, int offa) static voidcftxb020(float[] a, int offa) static voidcftxb020(org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidcftxb020(org.visnow.jlargearrays.FloatLargeArray a, long offa) static voidcftxc020(double[] a, int offa) static voidcftxc020(float[] a, int offa) static voidcftxc020(org.visnow.jlargearrays.DoubleLargeArray a, long offa) static voidcftxc020(org.visnow.jlargearrays.FloatLargeArray a, long offa) static voiddctsub(int n, double[] a, int offa, int nc, double[] c, int startc) static voiddctsub(int n, float[] a, int offa, int nc, float[] c, int startc) static voiddctsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nc, org.visnow.jlargearrays.DoubleLargeArray c, long startc) static voiddctsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nc, org.visnow.jlargearrays.FloatLargeArray c, long startc) static longgetReminder(long n, int[] factors) static longReturns the minimal size of 1D data for which two threads are used.static longReturns the minimal size of 1D data for which four threads are used.static longReturns the minimal size of 2D data for which threads are used.static longReturns the minimal size of 3D data for which threads are used.static booleanisPowerOf2(int x) Checks if x is a power-of-two number.static booleanisPowerOf2(long x) Checks if x is a power-of-two number.static booleanReturns the value of useLargeArrays variable.static voidmakect(int nc, double[] c, int startc, int[] ip) static voidmakect(int nc, float[] c, int startc, int[] ip) static voidmakect(long nc, org.visnow.jlargearrays.DoubleLargeArray c, long startc, org.visnow.jlargearrays.LongLargeArray ipl) static voidmakect(long nc, org.visnow.jlargearrays.FloatLargeArray c, long startc, org.visnow.jlargearrays.LongLargeArray ipl) static voidmakeipt(int nw, int[] ip) static voidmakeipt(long nw, org.visnow.jlargearrays.LongLargeArray ipl) static voidmakewt(int nw, int[] ip, double[] w) static voidmakewt(int nw, int[] ip, float[] w) static voidmakewt(long nw, org.visnow.jlargearrays.LongLargeArray ipl, org.visnow.jlargearrays.DoubleLargeArray wl) static voidmakewt(long nw, org.visnow.jlargearrays.LongLargeArray ipl, org.visnow.jlargearrays.FloatLargeArray wl) static intnextPow2(int x) Returns the closest power-of-two number greater than or equal to x.static longnextPow2(long x) Returns the closest power-of-two number greater than or equal to x.static intprevPow2(int x) Returns the closest power-of-two number less than or equal to x.static longprevPow2(long x) Returns the closest power-of-two number less than or equal to x.static voidResets the minimal size of 2D and 3D data for which threads are used.static voidResets the minimal size of 1D data for which two and four threads are used.static voidrftbsub(int n, double[] a, int offa, int nc, double[] c, int startc) static voidrftbsub(int n, float[] a, int offa, int nc, float[] c, int startc) static voidrftbsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nc, org.visnow.jlargearrays.DoubleLargeArray c, long startc) static voidrftbsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nc, org.visnow.jlargearrays.FloatLargeArray c, long startc) static voidrftfsub(int n, double[] a, int offa, int nc, double[] c, int startc) static voidrftfsub(int n, float[] a, int offa, int nc, float[] c, int startc) static voidrftfsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nc, org.visnow.jlargearrays.DoubleLargeArray c, long startc) static voidrftfsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nc, org.visnow.jlargearrays.FloatLargeArray c, long startc) static voidscale(int n, double m, double[] a, int offa, boolean complex) static voidscale(int n, float m, float[] a, int offa, boolean complex) static voidscale(long nl, double m, org.visnow.jlargearrays.DoubleLargeArray a, long offa, boolean complex) static voidscale(long nl, float m, org.visnow.jlargearrays.FloatLargeArray a, long offa, boolean complex) static voidsetThreadsBeginN_1D_FFT_2Threads(long n) Sets the minimal size of 1D data for which two threads are used.static voidsetThreadsBeginN_1D_FFT_4Threads(long n) Sets the minimal size of 1D data for which four threads are used.static voidsetThreadsBeginN_2D(long n) Sets the minimal size of 2D data for which threads are used.static voidsetThreadsBeginN_3D(long n) Sets the minimal size of 3D data for which threads are used.static voidsetUseLargeArrays(boolean useLargeArrays) Sets the value of useLargeArrays variable.static voidsleep(long millis) Causes the currently executing thread to sleep (temporarily cease execution) for the specified number of milliseconds.
-
Constructor Details
-
CommonUtils
public CommonUtils()
-
-
Method Details
-
sleep
public static void sleep(long millis) Causes the currently executing thread to sleep (temporarily cease execution) for the specified number of milliseconds.- Parameters:
millis- the length of time to sleep in milliseconds
-
getThreadsBeginN_1D_FFT_2Threads
public static long getThreadsBeginN_1D_FFT_2Threads()Returns the minimal size of 1D data for which two threads are used.- Returns:
- the minimal size of 1D data for which two threads are used
-
getThreadsBeginN_1D_FFT_4Threads
public static long getThreadsBeginN_1D_FFT_4Threads()Returns the minimal size of 1D data for which four threads are used.- Returns:
- the minimal size of 1D data for which four threads are used
-
getThreadsBeginN_2D
public static long getThreadsBeginN_2D()Returns the minimal size of 2D data for which threads are used.- Returns:
- the minimal size of 2D data for which threads are used
-
getThreadsBeginN_3D
public static long getThreadsBeginN_3D()Returns the minimal size of 3D data for which threads are used.- Returns:
- the minimal size of 3D data for which threads are used
-
setThreadsBeginN_1D_FFT_2Threads
public static void setThreadsBeginN_1D_FFT_2Threads(long n) Sets the minimal size of 1D data for which two threads are used.- Parameters:
n- the minimal size of 1D data for which two threads are used
-
setThreadsBeginN_1D_FFT_4Threads
public static void setThreadsBeginN_1D_FFT_4Threads(long n) Sets the minimal size of 1D data for which four threads are used.- Parameters:
n- the minimal size of 1D data for which four threads are used
-
setThreadsBeginN_2D
public static void setThreadsBeginN_2D(long n) Sets the minimal size of 2D data for which threads are used.- Parameters:
n- the minimal size of 2D data for which threads are used
-
setThreadsBeginN_3D
public static void setThreadsBeginN_3D(long n) Sets the minimal size of 3D data for which threads are used.- Parameters:
n- the minimal size of 3D data for which threads are used
-
resetThreadsBeginN_FFT
public static void resetThreadsBeginN_FFT()Resets the minimal size of 1D data for which two and four threads are used. -
resetThreadsBeginN
public static void resetThreadsBeginN()Resets the minimal size of 2D and 3D data for which threads are used. -
isUseLargeArrays
public static boolean isUseLargeArrays()Returns the value of useLargeArrays variable.- Returns:
- the value of useLargeArrays variable
-
setUseLargeArrays
public static void setUseLargeArrays(boolean useLargeArrays) Sets the value of useLargeArrays variable.- Parameters:
useLargeArrays- the value of useLargeArrays variable
-
nextPow2
public static int nextPow2(int x) Returns the closest power-of-two number greater than or equal to x.- Parameters:
x- input value- Returns:
- the closest power-of-two number greater than or equal to x
-
nextPow2
public static long nextPow2(long x) Returns the closest power-of-two number greater than or equal to x.- Parameters:
x- input value- Returns:
- the closest power-of-two number greater than or equal to x
-
prevPow2
public static int prevPow2(int x) Returns the closest power-of-two number less than or equal to x.- Parameters:
x- input value- Returns:
- the closest power-of-two number less then or equal to x
-
prevPow2
public static long prevPow2(long x) Returns the closest power-of-two number less than or equal to x.- Parameters:
x- input value- Returns:
- the closest power-of-two number less then or equal to x
-
isPowerOf2
public static boolean isPowerOf2(int x) Checks if x is a power-of-two number.- Parameters:
x- input value- Returns:
- true if x is a power-of-two number
-
isPowerOf2
public static boolean isPowerOf2(long x) Checks if x is a power-of-two number.- Parameters:
x- input value- Returns:
- true if x is a power-of-two number
-
getReminder
public static long getReminder(long n, int[] factors) -
makeipt
public static void makeipt(int nw, int[] ip) -
makeipt
public static void makeipt(long nw, org.visnow.jlargearrays.LongLargeArray ipl) -
makewt
public static void makewt(int nw, int[] ip, double[] w) -
makewt
public static void makewt(long nw, org.visnow.jlargearrays.LongLargeArray ipl, org.visnow.jlargearrays.DoubleLargeArray wl) -
makect
public static void makect(int nc, double[] c, int startc, int[] ip) -
makect
public static void makect(long nc, org.visnow.jlargearrays.DoubleLargeArray c, long startc, org.visnow.jlargearrays.LongLargeArray ipl) -
makect
public static void makect(int nc, float[] c, int startc, int[] ip) -
makect
public static void makect(long nc, org.visnow.jlargearrays.FloatLargeArray c, long startc, org.visnow.jlargearrays.LongLargeArray ipl) -
makewt
public static void makewt(int nw, int[] ip, float[] w) -
makewt
public static void makewt(long nw, org.visnow.jlargearrays.LongLargeArray ipl, org.visnow.jlargearrays.FloatLargeArray wl) -
cftfsub
public static void cftfsub(int n, double[] a, int offa, int[] ip, int nw, double[] w) -
cftfsub
public static void cftfsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.LongLargeArray ip, long nw, org.visnow.jlargearrays.DoubleLargeArray w) -
cftbsub
public static void cftbsub(int n, double[] a, int offa, int[] ip, int nw, double[] w) -
cftbsub
public static void cftbsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.LongLargeArray ip, long nw, org.visnow.jlargearrays.DoubleLargeArray w) -
bitrv2
public static void bitrv2(int n, int[] ip, double[] a, int offa) -
bitrv2l
public static void bitrv2l(long n, org.visnow.jlargearrays.LongLargeArray ip, org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
bitrv2conj
public static void bitrv2conj(int n, int[] ip, double[] a, int offa) -
bitrv2conj
public static void bitrv2conj(long n, org.visnow.jlargearrays.LongLargeArray ip, org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
bitrv216
public static void bitrv216(double[] a, int offa) -
bitrv216
public static void bitrv216(org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
bitrv216neg
public static void bitrv216neg(double[] a, int offa) -
bitrv216neg
public static void bitrv216neg(org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
bitrv208
public static void bitrv208(double[] a, int offa) -
bitrv208
public static void bitrv208(org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
bitrv208neg
public static void bitrv208neg(double[] a, int offa) -
bitrv208neg
public static void bitrv208neg(org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
cftf1st
public static void cftf1st(int n, double[] a, int offa, double[] w, int startw) -
cftf1st
public static void cftf1st(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) -
cftb1st
public static void cftb1st(int n, double[] a, int offa, double[] w, int startw) -
cftb1st
public static void cftb1st(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) -
cftrec4_th
public static void cftrec4_th(int n, double[] a, int offa, int nw, double[] w) -
cftrec4_th
public static void cftrec4_th(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) -
cftrec4
public static void cftrec4(int n, double[] a, int offa, int nw, double[] w) -
cftrec4
public static void cftrec4(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) -
cfttree
public static int cfttree(int n, int j, int k, double[] a, int offa, int nw, double[] w) -
cfttree
public static long cfttree(long n, long j, long k, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) -
cftleaf
public static void cftleaf(int n, int isplt, double[] a, int offa, int nw, double[] w) -
cftleaf
public static void cftleaf(long n, long isplt, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) -
cftmdl1
public static void cftmdl1(int n, double[] a, int offa, double[] w, int startw) -
cftmdl1
public static void cftmdl1(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) -
cftmdl2
public static void cftmdl2(int n, double[] a, int offa, double[] w, int startw) -
cftmdl2
public static void cftmdl2(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) -
cftfx41
public static void cftfx41(int n, double[] a, int offa, int nw, double[] w) -
cftfx41
public static void cftfx41(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nw, org.visnow.jlargearrays.DoubleLargeArray w) -
cftf161
public static void cftf161(double[] a, int offa, double[] w, int startw) -
cftf161
public static void cftf161(org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) -
cftf162
public static void cftf162(double[] a, int offa, double[] w, int startw) -
cftf162
public static void cftf162(org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) -
cftf081
public static void cftf081(double[] a, int offa, double[] w, int startw) -
cftf081
public static void cftf081(org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) -
cftf082
public static void cftf082(double[] a, int offa, double[] w, int startw) -
cftf082
public static void cftf082(org.visnow.jlargearrays.DoubleLargeArray a, long offa, org.visnow.jlargearrays.DoubleLargeArray w, long startw) -
cftf040
public static void cftf040(double[] a, int offa) -
cftf040
public static void cftf040(org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
cftb040
public static void cftb040(double[] a, int offa) -
cftb040
public static void cftb040(org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
cftx020
public static void cftx020(double[] a, int offa) -
cftx020
public static void cftx020(org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
cftxb020
public static void cftxb020(double[] a, int offa) -
cftxb020
public static void cftxb020(org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
cftxc020
public static void cftxc020(double[] a, int offa) -
cftxc020
public static void cftxc020(org.visnow.jlargearrays.DoubleLargeArray a, long offa) -
rftfsub
public static void rftfsub(int n, double[] a, int offa, int nc, double[] c, int startc) -
rftfsub
public static void rftfsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nc, org.visnow.jlargearrays.DoubleLargeArray c, long startc) -
rftbsub
public static void rftbsub(int n, double[] a, int offa, int nc, double[] c, int startc) -
rftbsub
public static void rftbsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nc, org.visnow.jlargearrays.DoubleLargeArray c, long startc) -
dctsub
public static void dctsub(int n, double[] a, int offa, int nc, double[] c, int startc) -
dctsub
public static void dctsub(long n, org.visnow.jlargearrays.DoubleLargeArray a, long offa, long nc, org.visnow.jlargearrays.DoubleLargeArray c, long startc) -
cftfsub
public static void cftfsub(int n, float[] a, int offa, int[] ip, int nw, float[] w) -
cftfsub
public static void cftfsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.LongLargeArray ip, long nw, org.visnow.jlargearrays.FloatLargeArray w) -
cftbsub
public static void cftbsub(int n, float[] a, int offa, int[] ip, int nw, float[] w) -
cftbsub
public static void cftbsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.LongLargeArray ip, long nw, org.visnow.jlargearrays.FloatLargeArray w) -
bitrv2
public static void bitrv2(int n, int[] ip, float[] a, int offa) -
bitrv2l
public static void bitrv2l(long n, org.visnow.jlargearrays.LongLargeArray ip, org.visnow.jlargearrays.FloatLargeArray a, long offa) -
bitrv2conj
public static void bitrv2conj(int n, int[] ip, float[] a, int offa) -
bitrv2conj
public static void bitrv2conj(long n, org.visnow.jlargearrays.LongLargeArray ip, org.visnow.jlargearrays.FloatLargeArray a, long offa) -
bitrv216
public static void bitrv216(float[] a, int offa) -
bitrv216
public static void bitrv216(org.visnow.jlargearrays.FloatLargeArray a, long offa) -
bitrv216neg
public static void bitrv216neg(float[] a, int offa) -
bitrv216neg
public static void bitrv216neg(org.visnow.jlargearrays.FloatLargeArray a, long offa) -
bitrv208
public static void bitrv208(float[] a, int offa) -
bitrv208
public static void bitrv208(org.visnow.jlargearrays.FloatLargeArray a, long offa) -
bitrv208neg
public static void bitrv208neg(float[] a, int offa) -
bitrv208neg
public static void bitrv208neg(org.visnow.jlargearrays.FloatLargeArray a, long offa) -
cftf1st
public static void cftf1st(int n, float[] a, int offa, float[] w, int startw) -
cftf1st
public static void cftf1st(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) -
cftb1st
public static void cftb1st(int n, float[] a, int offa, float[] w, int startw) -
cftb1st
public static void cftb1st(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) -
cftrec4_th
public static void cftrec4_th(int n, float[] a, int offa, int nw, float[] w) -
cftrec4_th
public static void cftrec4_th(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) -
cftrec4
public static void cftrec4(int n, float[] a, int offa, int nw, float[] w) -
cftrec4
public static void cftrec4(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) -
cfttree
public static int cfttree(int n, int j, int k, float[] a, int offa, int nw, float[] w) -
cfttree
public static long cfttree(long n, long j, long k, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) -
cftleaf
public static void cftleaf(int n, int isplt, float[] a, int offa, int nw, float[] w) -
cftleaf
public static void cftleaf(long n, long isplt, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) -
cftmdl1
public static void cftmdl1(int n, float[] a, int offa, float[] w, int startw) -
cftmdl1
public static void cftmdl1(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) -
cftmdl2
public static void cftmdl2(int n, float[] a, int offa, float[] w, int startw) -
cftmdl2
public static void cftmdl2(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) -
cftfx41
public static void cftfx41(int n, float[] a, int offa, int nw, float[] w) -
cftfx41
public static void cftfx41(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nw, org.visnow.jlargearrays.FloatLargeArray w) -
cftf161
public static void cftf161(float[] a, int offa, float[] w, int startw) -
cftf161
public static void cftf161(org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) -
cftf162
public static void cftf162(float[] a, int offa, float[] w, int startw) -
cftf162
public static void cftf162(org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) -
cftf081
public static void cftf081(float[] a, int offa, float[] w, int startw) -
cftf081
public static void cftf081(org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) -
cftf082
public static void cftf082(float[] a, int offa, float[] w, int startw) -
cftf082
public static void cftf082(org.visnow.jlargearrays.FloatLargeArray a, long offa, org.visnow.jlargearrays.FloatLargeArray w, long startw) -
cftf040
public static void cftf040(float[] a, int offa) -
cftf040
public static void cftf040(org.visnow.jlargearrays.FloatLargeArray a, long offa) -
cftb040
public static void cftb040(float[] a, int offa) -
cftb040
public static void cftb040(org.visnow.jlargearrays.FloatLargeArray a, long offa) -
cftx020
public static void cftx020(float[] a, int offa) -
cftx020
public static void cftx020(org.visnow.jlargearrays.FloatLargeArray a, long offa) -
cftxb020
public static void cftxb020(float[] a, int offa) -
cftxb020
public static void cftxb020(org.visnow.jlargearrays.FloatLargeArray a, long offa) -
cftxc020
public static void cftxc020(float[] a, int offa) -
cftxc020
public static void cftxc020(org.visnow.jlargearrays.FloatLargeArray a, long offa) -
rftfsub
public static void rftfsub(int n, float[] a, int offa, int nc, float[] c, int startc) -
rftfsub
public static void rftfsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nc, org.visnow.jlargearrays.FloatLargeArray c, long startc) -
rftbsub
public static void rftbsub(int n, float[] a, int offa, int nc, float[] c, int startc) -
rftbsub
public static void rftbsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nc, org.visnow.jlargearrays.FloatLargeArray c, long startc) -
dctsub
public static void dctsub(int n, float[] a, int offa, int nc, float[] c, int startc) -
dctsub
public static void dctsub(long n, org.visnow.jlargearrays.FloatLargeArray a, long offa, long nc, org.visnow.jlargearrays.FloatLargeArray c, long startc) -
scale
public static void scale(int n, double m, double[] a, int offa, boolean complex) -
scale
public static void scale(long nl, double m, org.visnow.jlargearrays.DoubleLargeArray a, long offa, boolean complex) -
scale
public static void scale(int n, float m, float[] a, int offa, boolean complex) -
scale
public static void scale(long nl, float m, org.visnow.jlargearrays.FloatLargeArray a, long offa, boolean complex)
-